@@ -29,7 +29,7 @@ our ( $Indent, $Trailingcomma, $Purity, $Pad, $Varname, $Useqq, $Terse, $Freezer
 our ( @ISA, @EXPORT, @EXPORT_OK, $VERSION );
 
 BEGIN {
-    $VERSION = '2.180_50'; # Don't forget to set version and release
+    $VERSION = '2.180_51'; # Don't forget to set version and release
                         # date in POD below!
 
     @ISA = qw(Exporter);
@@ -542,13 +542,26 @@ sub _dump {
     elsif (!defined($val)) {
       $out .= "undef";
     }
+    # This calls the XSUB _vstring (if the XS code is loaded). I'm not *sure* if
+    # if belongs in the "Pure Perl" implementation. It sort of depends on what
+    # was meant by "Pure Perl", as this subroutine already relies Scalar::Util
+    # loading, which means that it has an XS dependency. De facto, it's the
+    # "Pure Perl" implementation of dumping (which uses XS helper code), as
+    # opposed to the C implementation (which calls out to Perl helper code).
+    # So in that sense this is fine - it just happens to be a local XS helper.
     elsif (defined &_vstring and $v = _vstring($val)
       and !_bad_vsmg || eval $v eq $val) {
       $out .= $v;
     }
+    # However the confusion comes here - if we *can't* find our XS helper, we
+    # fall back to this code, which generates different (worse) results. That's
+    # better than nothing, *but* it means that if you run the regression tests
+    # with Dumper.so missing, the test for "vstrings" fails, because this code
+    # here generates a different result. So there are actually "three" different
+    # implementations of Data::Dumper (kind of sort of) but we only test two.
     elsif (!defined &_vstring
        and ref $ref eq 'VSTRING' || eval{Scalar::Util::isvstring($val)}) {
-      $out .= sprintf "%vd", $val;
+      $out .= sprintf "v%vd", $val;
     }
     # \d here would treat "1\x{660}" as a safe decimal number
     elsif ($val =~ /^(?:0|-?[1-9][0-9]{0,8})\z/) { # safe decimal number
@@ -1439,7 +1452,7 @@ modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-Version 2.180_50
+Version 2.180_51
 
 =head1 SEE ALSO
 
